<?php if (!defined('SMP_VER')) exit('restricted access');
/*
 * @package WordPress
 * @subpackage Simp Modal Window
*/
	// get plugin settings
	$settings = get_option('simp_settings');
	
	/* load jquery js if user want to load, if theme has not loaded jquery
	* else if theme has an instance of jquery already loaded, select "No" from seetings */
	
	if (!is_admin() && $settings['jquery'] != 'no') {
		// add jquery script init
		add_action('init', 'add_popup_script_init');

		function add_popup_script_init() {
			global $settings;
			
			// load jquery loacl copy
			if ($settings['jquery'] == 'yes') {
				
				// enqueue jquery script
				wp_enqueue_script( 'jquery-lc', SMP_URL .'js/jquery.min.js', '', '1.11.0' );
				
			} elseif ($settings['jquery'] == 'cdn') {
				
				// load jquery from google CDN
				wp_enqueue_script( 'jquery-cdn', '//ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js', '', '1.11.1' );
			}
		}
	}
	
	// get cookie data from settings
	function get_cookie_values($id) {
		
		// get values from modal post meta array
		$set = get_modal_settings($id);
		$display = $set['display'];
		$cookie = $set['cookie'];
		$cookie_dur = $set['cookie_dur'];
		$cookie_date = $set['cookie_date'];
		
		if (can_display_modal($id)) {
			$return = true;
			
			// check if cookie enabled
			if ($cookie == 'yes') {
			
				// get current time
				$time = time();
				
				// show once set ten years
				if ($cookie_dur == '1time') {
					$exp = 315569260 + $time;
				} elseif ($cookie_dur == '6hr') {
					// show after every 6 hours
					$exp = 21600 + $time;
				} elseif ($cookie_dur == '12hr') {
					// show after every 12 hours
					$exp = 43200 + $time;
				} elseif ($cookie_dur == '24hr') {
					// show after every 24 hours
					$exp = 86400 + $time;
				} elseif ($cookie_dur == '2day') {
					// show after every 2 days
					$exp = 172800 + $time;
				} elseif ($cookie_dur == '3day') {
					// show after every 3 days
					$exp = 259200 + $time;
				} elseif ($cookie_dur == '1week') {
					// show after every week
					$exp = 604800 + $time;
				} elseif ($cookie_dur == '2week') {
					// show after every 2 weeks
					$exp = 1209600 + $time;
				} elseif ($cookie_dur == 'month') {
					// show after every 1 month
					$exp = 2629743 + $time;
				} elseif ($cookie_dur == 'expire') {
					// show after specific time
					$cookie_time = strtotime($cookie_date);
					$exp = $cookie_time + $time;
				}
				
				// get old cookie if present
				$new_cookie = 'visited' .$id;
				$old_cookie = $_COOKIE[$new_cookie];
				
				// set a new cookie based on settings
				if (!isset($old_cookie)) {
					// new cookie array
					$return = array(
						'id' => $new_cookie,
						'exp' => $exp
					);
				} else {
					$return = false;
				}
			}
			return $return;
		}
	}
	
	// add popup css styles into wp_head
	add_action('wp_head', 'add_popup_styles_head', 99);
	
	function add_popup_styles_head() {
		
		// get design data
		$modals = get_modal_settings_data();
		
		if (is_array($modals)) {
			// init $out var
			$out = '';
			
			foreach ($modals as $modal) {
				
				if ($modal != '') {
					
					// generate css styles based on user inputs
					$design = get_post_meta( $modal, 'popup_design_meta', true );
					$width = $design['width'];
					$units = $design['units'];
					$height = $design['height'];
					$padding = $design['padding'];
					$background = $design['background'];
					$border_radius = $design['border_radius'];
					$border = $design['border'];
					$border_style = $design['border_style'];
					$border_color = $design['border_color'];
					$overlay = $design['overlay'];
					$overlay_opacity = $design['overlay_opacity'];
					$overlay_color = $design['overlay_color'];
					$shadow = $design['shadow'];
					$shadow_opacity = $design['shadow_opacity'];
					$shadow_color = $design['shadow_color'];
					$close = $design['close'];
					$close_position = $design['close_position'];
					$close_icon = $design['close_icon'];
					$custom_css = $design['custom_css'];
					
					// units values
					if ($units == 'per') {
						$units = '%';
					} else {
						$units = 'px';
					}
					// get settings
					$set = get_modal_settings($modal);
					$auto = $set['auto'];
					$counter = $set['counter'];
					$counter_c = $set['counter_c'];
					
					// check if overlay enabled from settings
					if ($overlay == 'yes') { $out .= '#modal-bg' .$modal .' {background:' .$overlay_color .';} '; }
					$out .= '#modal-window' .$modal .' {width:' .$width .$units .'; height:' .$height .$units .';';
					$margin_left = $width / 2;
					$margin_left = $margin_left + $padding;
					$out .= 'margin-left:-' .$margin_left .$units .';';
					$margin_top = $height / 2;
					$margin_top = $margin_top + $padding;
					$out .= 'margin-top:-' .$margin_top .$units .';';
					$out .= 'background:' .$background .';';
					
					// check if border radius value entered
					if ($border_radius != '') { $out .= '-moz-border-radius:' .$border_radius .'px; -webkit-border-radius:' .$border_radius .'px; border-radius:' .$border_radius .'px;'; }
					
					// check if box shadow values entered
					if ($shadow != 'no') {
						$shadow_rgba = simp_hex2rgb($shadow_color) .',' .$shadow_opacity;
						$out .= 'box-shadow:0 0 ' .$shadow .' rgba(' .$shadow_rgba .'); -webkit-box-shadow:0 0 ' .$shadow .' rgba(' .$shadow_rgba .'); -moz-box-shadow:0 0 ' .$shadow .' rgba(' .$shadow_rgba .');';
					}
					
					// check if border values entered
					if ($border != 'none') { $out .= 'border:' .$border .' ' .$border_style .' ' .$border_color .';'; }
					
					// check if modal has padding
					if ($padding) { $out .= 'padding:' .$padding .$units .'; '; }
					$out .= '} ';
					
					// check if close icon is enabled
					if ($close == 'yes') {
						$out .= 'span.close-modal' .$modal .' {height:24px; width:24px; position:absolute; cursor:pointer;';
						if ($close_position == 'tl') {
							$out .= 'top:-8px; left:-8px;';
						} elseif ($close_position == 'tr') {
							$out .= 'top:-8px; right:-8px;';
						} elseif ($close_position == 'bl') {
							$out .= 'bottom:-8px; left:-8px;';
						} elseif ($close_position == 'br') {
							$out .= 'bottom:-8px; right:-8px;';
						}
						$out .= 'background:url(' .SMP_URL .'images/close' .$close_icon .'.png) 0 0 no-repeat;} ';
					} else {
						// if close icon not enabled
						$out .= 'span.close-modal' .$modal .' {display:none;} ';
					}
					
					// if auto close enabled
					if ($auto != 'no' && $counter != 'no') {
						$out .= 'span#modal-counter' .$modal .' { ';
						// if counter display top left
						if ($counter == 'tl') {
							$out .= 'top:2px; left:3px; ';
						}
						// if counter display top right
						if ($counter == 'tr') {
							$out .= 'top:2px; right:3px; ';
						}
						// if counter display bottom left
						if ($counter == 'bl') {
							$out .= 'bottom:2px; left:3px; ';
						}
						// if counter display bottom right
						if ($counter == 'br') {
							$out .= 'bottom:2px; right:3px; ';
						}
						// counter text color
						$out .= 'color:' .$counter_c .'; } ';
					}
					
					// modal content styles
					$out .= $custom_css;
				}
			}
		}
		
		$out_s = '<style type="text/css">';
		// overlay bg styles
		$out_s .= '.modal-bg {width:100%; height:100%; position:fixed; z-index:991; display:none; top:0; left:0;} ';
		$out_s .= '.modal-window {visibility:hidden; position:fixed; z-index:-1; opacity:0; left:50%; top:50%;} ';
		$out_s .= 'span.modal-counter {position:absolute; font-size:10px;} ';
		
		// end styles
		$out_e = '</style>' ."\r\n";
		
		// print css styles
		echo $out_s .$out .$out_e; 
	}

	// add output into wp_footer
	add_action('wp_footer', 'add_popup_wp_footer', 99);

	function add_popup_wp_footer() {
		
		$modals = get_modal_settings_data();
		
		$i = 0; // reset counter
		$cs = 0;
		$ds = 0;
		
		if (is_array($modals)) {
			foreach ($modals as $modal) {
				// get cookie settings
				$set_cookie = get_cookie_values($modal);
				
				if ($modal != '' && $set_cookie != false) {
					
					// get modal data
					$set = get_modal_settings($modal);
					$display = $set['display'];
					$close_msg = $set['close_msg'];
					if ($close_msg == '') { $close_msg = 'Wait Check Our Last Minute Deal.'; }
					$display_button = $set['display_button'];
					$auto = $set['auto'];
					$counter = $set['counter'];
					$transition = $set['transition'];
					$animation = $set['animation'];
					$hide_click = $set['hide_click'];
					$design = get_post_meta( $modal, 'popup_design_meta', true );
					$overlay_opacity = $design['overlay_opacity'];
					
					// make an array of available methods
					$methods = array('load5s', 'load10s', 'load15s', 'load20s', 'load30s', 'load45s', 'load1m', 'load2m', 'load3m', 'load5m');
					
					// get timeout value
					switch ($display) {
						// timout 5 seconds
						case 'load5s' : $timeout = '5000'; break;
						// timout 10 seconds
						case 'load10s' : $timeout = '10000'; break;
						// timout 15 seconds
						case 'load15s' : $timeout = '15000'; break;
						// timout 20 seconds
						case 'load20s' : $timeout = '20000'; break;
						// timout 30 seconds
						case 'load30s' : $timeout = '30000'; break;
						// timout 45 seconds
						case 'load45s' : $timeout = '45000'; break;
						// timout 1 minute
						case 'load1m' : $timeout = '60000'; break;
						// timout 2 minutes
						case 'load2m' : $timeout = '120000'; break;
						// timout 3 minutes
						case 'load3m' : $timeout = '180000'; break;
						// timout 5 minutes
						case 'load5m' : $timeout = '300000'; break;
					}
					
					// get modal content
					$post = get_post($modal);
					$output .= '<div id="modal-window' .$modal .'" class="modal-window">' .do_shortcode($post->post_content);
					$output .= '<span class="close-modal' .$modal .'"></span>';
					// if auto clse and counter is enabled
					if ($auto != 'no' && $counter != 'no') {
						$output .= '<span class="modal-counter" id="modal-counter' .$modal .'"></span>';
					}
					$output .= '</div>' ."\r\n";
					
					// if we need to set a cookie
					if ($set_cookie['id'] != '' && $cs == 0) {
						$cookie_script = true;
						$cs = 1; 
					}
					
					// if first modal in loop
					if ($i == 0) {
						$modal_script = true;
						$script = '<script type="text/javascript">';
						$i = 1;
					}
					
					// if modal display on unload
					if ($display == 'unload') {
						$script .= '(function($) { ';
						$script .= 'window.onbeforeunload = function(ue) { ';
					} else {
						$script .= 'jQuery(document).ready(function($) { ';
					}
					
					// if modal display after xtime
					if (in_array($display, $methods)) {
						$script .= 'setTimeout(function() { ';
					}
					
					// if cookie id not empty
					if ($set_cookie['id'] != '') {
						$script .= 'var expDate' .$i .' = new Date(' .$set_cookie['exp'] .' * 1000); ';
						$script .= '$.cookie("' .$set_cookie['id'] .'", 1, {expires: expDate' .$i .', path: "/"}); ';
						
					}
					
					// if modal display onclick
					if ($display == 'click') {
						$script .= '$("' .$display_button .'").click(function(e) { ';
						$script .= 'e.preventDefault(); ';
					}
					
					$script .= '$("#modal-window' .$modal .'").reveal({ ';
					$script .= 'animation: "' .$transition .'", ';
					$script .= 'animationspeed: ' .$animation .', ';
					$script .= 'closeonbackgroundclick: ' .$hide_click .', ';
					$script .= 'dismissmodalclass:"close-modal' .$modal .'", ';
					$script .= 'modalbgid:"modal-bg' .$modal .'", ';
					$script .= 'bgopacity:' .$overlay_opacity;
					$script .= ' }); ';
					
					// autoclose after x time
					if ($auto != 'no') {
						$script .= 'var delayValue' .$modal .' = ' .$auto .'; ';
						$script .= 'if (delayValue' .$modal .' != 0) { ';
						$script .= 'countdown' .$modal .' = delayValue' .$modal .'; ';
						$script .= 'timeout' .$modal .' = setTimeout(simpModalCounter' .$modal .', 1000); } ';
					}
					
					// if modal display onclick
					if ($display == 'click') {
						$script .= ' }); ';
					}
					
					// if modal display after xtime
					if (in_array($display, $methods)) {
						$script .= ' }, ' .$timeout .'); ';
					}
					
					// end script
					if ($display == 'unload') {
						$script .= 'ue.preventDefault(); ';
						$script .= 'ue.stopPropagation(); ';
						$script .= 'ue.stopImmediatePropagation(); ';
						$script .= 'return "' .$close_msg .'"; ';
						$script .= '} })(jQuery); ';
					} else {
						$script .= '}); ';
					}
					
					// autoclose after x time
					if ($auto != 'no') {
						$script .= 'function simpModalCounter' .$modal .'() { ';
						$script .= 'if (countdown' .$modal .' == 0) { ';
						$script .= 'jQuery("#modal-window' .$modal .'").trigger("reveal:close"); ';
						$script .= '} else { countdown' .$modal .' = countdown' .$modal .' - 1; ';
						$script .= 'jQuery("#modal-counter' .$modal .'").html(simpModalCountDown(countdown' .$modal .')); ';
						$script .= 'timeout' .$modal .' = setTimeout(simpModalCounter' .$modal .', 1000); } } ';
						
						// include function only once
						if ($ds == 0) {
							$script .= 'function simpModalCountDown(value) { ';
							$script .= 'var result = ""; ';
							$script .= 'var minutes = Math.floor(value / 60); ';
							$script .= 'var seconds = value % 60; ';
							$script .= 'if (minutes > 9) { result = minutes.toString() + ":"; ';
							$script .= '} else { result = "0" + minutes.toString() + ":"; } ';
							$script .= 'if (seconds > 9) { result = result + seconds.toString(); ';
							$script .= '} else { result = result + "0" + seconds.toString(); } ';
							$script .= 'return result; } ';
							$ds = 1;
						}
					}
					
					// position center the modal ever
					$script .= 'jQuery(window).bind("load resize", function() { ';
					$script .= 'var modBox = jQuery("#modal-window' .$modal .'"); ';
					$script .= 'var modHeight = modBox.outerHeight(); ';
					$script .= 'var modWidth = modBox.outerWidth(); ';
					$script .= 'var modMarTop = modHeight / 2; ';
					$script .= 'var modMarLeft = modWidth / 2; ';
					$script .= 'modBox.css({marginTop: "-" + modMarTop + "px", marginLeft: "-" + modMarLeft + "px"}); ';
					$script .= '}); ';
				}
			}
			$script .= '</script>';
		}
		
		// cookie js need to print
		if ($cookie_script) {
			// print jquery cookie js script
			wp_print_scripts( 'cookie-js' );
		}
		
		// if modal js need to print
		if ($modal_script) {
			// print modal jquery script
			wp_print_scripts( 'modal-js' );
		}
		
		// if output, print it
		if ($output) {
			// print output
			echo $output ."\r\n";
		}
		
		// if script, print it
		if ($script) {
			// print script
			echo $script ."\r\n";
		}
	}

	// check modal window is enabled for current post
	function get_modal_settings_data() {
		global $post;
		
		// reset posts query
		wp_reset_query();
		
		// get post id
		$postID = $post->ID;
		
		// get all modal windows
		$modal_query = new WP_Query(
			array(
				'post_type' => 'popups',
				'posts_per_page' => -1
			)
		);
		
		$modals = array();
		
		// start modal windows loop
		if ($modal_query->have_posts()) :
			while ($modal_query->have_posts()) :
				$modal_query->the_post();
				
				// check if modal enabled for current page/post
				if (can_display_modal($post->ID)) {
					$modals[] = $post->ID;
				}
				
			endwhile;
		endif;
		
		// reset posts query
		wp_reset_postdata();
		
		// check modal stats
		$return = array();
		foreach ($modals as $modal) {
			$return[] = get_modal_stats($modal, $postID);
		}
		// return modal settings
		return $return;
	}
	
	// get modal stats by post id
	function get_modal_stats($modID, $postID) {
		// get modal settings from post meta
		$settings = get_modal_settings($modID);
		$display_on = $settings['display_on'];
		$display_ids = $settings['display_ids'];
		$display_ids = explode(',', $display_ids);
		
		// check if current post has modal window
		$modal = false;
		
		// check if modal display on all pages
		if ($display_on == 'all-pages') {
			if (!is_search() && is_page($postID)) $modal = $modID;
			
			// check if modal display on all posts
		} elseif ($display_on == 'index-page') {
			if (!is_search() && is_home()) $modal = $modID;
			
			// check if modal display on all pages and posts
		}  elseif ($display_on == 'all-posts') {
			if (!is_search() && is_single($postID)) $modal = $modID;
			
			// check if modal display on all pages and posts
		} elseif ($display_on == 'pages-posts') {
			$modal = $modID;
			
			// check if modal display on archives
		} elseif ($display_on == 'archive') {
			if (is_archive()) $modal = $modID;
			
			// check if modal display only on search pages
		} elseif ($display_on == 'search') {
			if (is_search() && !is_page()) $modal = $modID;
			
			// check if modal display only on specific posts/pages
		} elseif ($display_on == 'only-specific') {
			if (in_array($postID, $display_ids)) $modal = $modID;
			
			// check if modal don't display on specific pages/posts
		} elseif ($display_on == 'exc-specific') {
			if (!in_array($postID, $display_ids)) $modal = $modID;
		} else {
			if (!is_search() && $display_on == $postID) $modal = $modID;
		}
		
		return $modal;
	}
	
	// get modal settings from post meta
	function get_modal_settings($id) {
		return get_post_meta( $id, 'popup_set_meta', true );
	}
	
	// check if popup need to show
	function can_display_modal($id) {
		// get modal settings
		$settings = get_modal_settings($id);
		$display = $settings['display'];
		
		// make an array of available methods
		$methods = array('click', 'load', 'unload', 'load5s', 'load10s', 'load15s', 'load20s', 'load30s', 'load45s', 'load1m', 'load2m', 'load3m', 'load5m');
		
		if (in_array($display, $methods)) {
			return true;
		} else {
			return false;
		}
	}
	
	// convert hex color to rgb
	function simp_hex2rgb($hex) {
		$hex = str_replace('#', '', $hex);

		$r = hexdec(substr($hex,0,2));
		$g = hexdec(substr($hex,2,2));
		$b = hexdec(substr($hex,4,2));
		$rgb = array($r, $g, $b);
		// returns the rgb values separated by commas
		return implode(',', $rgb);
	}
?>